@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v0.708.3.0';
+our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
 
 use Tie::IxHash;
 use Carp 'carp';
@@ -433,7 +433,7 @@ sub legacy_remove {
     my ($just_one, $safe);
     if (defined $options && ref $options eq 'HASH') {
         $just_one = exists $options->{just_one} ? $options->{just_one} : 0;
-        $safe = $options->{safe} or $conn->_w_want_safe;
+        $safe = $options->{safe} || $conn->_w_want_safe;
     }
     else {
         $just_one = $options || 0;
@@ -717,7 +717,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v0.708.3.0
+version v0.708.4.0
 
 =head1 SYNOPSIS
 
