@@ -1429,6 +1429,16 @@ append_sv (bson_t * bson, const char * in_key, SV *sv, stackette *stack, int is_
     }
 #endif
 
+#if PERL_REVISION==5 && PERL_VERSION<=18
+    /* Before 5.18, get magic would clear public flags. This restores them
+     * from private flags but ONLY if there is no public flag already, as
+     * we have nothing else to go on for serialization.
+     */
+    if (!(SvFLAGS(sv) & (SVf_IOK|SVf_NOK|SVf_POK))) {
+        SvFLAGS(sv) |= (SvFLAGS(sv) & (SVp_IOK|SVp_NOK|SVp_POK)) >> PRIVSHIFT;
+    }
+#endif
+
     if (look_for_numbers && SvIOK(look_for_numbers) && SvIV(look_for_numbers)) {
       aggressively_number = looks_like_number(sv);
     }
